%define anolis_release 1

# Many softwares in the running dependency chain of oscilloscope have not been introduced into Anolis 23,
# so package oscilloscope is temporarily canceled.
%bcond_with oscilloscope

Name:           tuna
Version:        0.18
Release:        %{anolis_release}%{?dist}
License:        GPLv2
Summary:        Application tuning GUI & command line utility
Source:         https://git.kernel.org/pub/scm/utils/%{name}/%{name}.git/snapshot/%{name}-%{version}.tar.gz
URL:            https://rt.wiki.kernel.org/index.php/Tuna
BuildArch:      noarch
BuildRequires:  python3-devel, gettext
Requires:       python3-ethtool
Requires:       python3-linux-procfs >= 0.6
Requires:       python3-schedutils >= 0.6

%description
Provides interface for changing scheduler and IRQ tunables, at whole CPU and at
per thread/IRQ level. Allows isolating CPUs for use by a specific application
and moving threads and interrupts to a CPU by just dragging and dropping them.
Operations can be done on CPU sockets, understanding CPU topology.

Can be used as a command line utility without requiring the GUI libraries to be
installed.

%if %{with oscilloscope}
%package -n oscilloscope
Summary:        Generic graphical signal plotting tool
Requires:       python3-matplotlib-gtk3
Requires:       python3-numpy
Requires:       python3-cairocffi
Requires:       gobject-introspection
Requires:       %{name} = %{version}-%{release}

%description -n oscilloscope
Plots stream of values read from standard input on the screen together with
statistics and a histogram.

Allows to instantly see how a signal generator, such as cyclictest, signaltest
or even ping, reacts when, for instance, its scheduling policy or real time
priority is changed, be it using tuna or plain chrt & taskset.
%endif

%package doc
Summary:        doc for tuna
Requires:       %{name} = %{version}-%{release}
License:        GPLv2
BuildArch:      noarch

%description doc
Provides interface for changing scheduler and IRQ tunables, at whole CPU and at
per thread/IRQ level. Allows isolating CPUs for use by a specific application
and moving threads and interrupts to a CPU by just dragging and dropping them.
Operations can be done on CPU sockets, understanding CPU topology.

Can be used as a command line utility without requiring the GUI libraries to be
installed.

%prep
%autosetup -p1

%build
%py3_build
pathfix.py -pni "%{__python3} %{py3_shbang_opts}" tuna/
pathfix.py -pni "%{__python3} %{py3_shbang_opts}" tuna-cmd.py
%if %{with oscilloscope}
pathfix.py -pni "%{__python3} %{py3_shbang_opts}" oscilloscope-cmd.py
%endif

%install
rm -rf %{buildroot}
%py3_install
mkdir -p %{buildroot}/%{_sysconfdir}/tuna/
mkdir -p %{buildroot}/{%{_bindir},%{_datadir}/tuna/help/kthreads,%{_mandir}/man8}
mkdir -p %{buildroot}/%{_datadir}/polkit-1/actions/
install -p -m644 tuna/tuna_gui.glade %{buildroot}/%{_datadir}/tuna/
install -p -m755 tuna-cmd.py %{buildroot}/%{_bindir}/tuna
%if %{with oscilloscope}
install -p -m755 oscilloscope-cmd.py %{buildroot}/%{_bindir}/oscilloscope
%endif
install -p -m644 help/kthreads/* %{buildroot}/%{_datadir}/tuna/help/kthreads/
install -p -m644 docs/tuna.8 %{buildroot}/%{_mandir}/man8/
install -p -m644 etc/tuna/example.conf %{buildroot}/%{_sysconfdir}/tuna/
install -p -m644 etc/tuna.conf %{buildroot}/%{_sysconfdir}/
install -p -m644 org.tuna.policy %{buildroot}/%{_datadir}/polkit-1/actions/
 
# l10n-ed message catalogues
for lng in `cat po/LINGUAS`; do
        po=po/"$lng.po"
        mkdir -p %{buildroot}/%{_datadir}/locale/${lng}/LC_MESSAGES
        msgfmt $po -o %{buildroot}/%{_datadir}/locale/${lng}/LC_MESSAGES/%{name}.mo
done

%find_lang %name
%files -f %{name}.lang
%{python3_sitelib}/*.egg-info
%{_bindir}/tuna
%{_datadir}/tuna/
%{python3_sitelib}/tuna/
%{_mandir}/man8/tuna.8*
%{_sysconfdir}/tuna.conf
%{_sysconfdir}/tuna/*
%{_datadir}/polkit-1/actions/org.tuna.policy

%if %{with oscilloscope}
%files -n oscilloscope
%{_bindir}/oscilloscope
%endif

%files doc
%doc ChangeLog
%if %{with oscilloscope}
%doc docs/oscilloscope+tuna.html
%doc docs/oscilloscope+tuna.pdf
%endif

%changelog
* Fri Dec 23 2022 Feng Su <sufeng@linux.alibaba.com> - 0.18-1
- initial  packaging for Anolis 23
